@@ -24,7 +24,9 @@ Boston, MA 02110-1301, USA.
 #include <QtCore/QObject>
 
 #include <ksharedconfig.h>
+#include <kurl.h>
 
+struct QUuid;
 class QString;
 class KUrl;
 
@@ -43,9 +45,25 @@ public:
     ISession( QObject* parent = 0 );
     virtual ~ISession();
 
+    /**
+     * A short string nicely identifying the session, including contained projects
+     * 
+     * The string is empty if the session is empty and has no name.
+     */
+    virtual QString description() const = 0;
     virtual QString name() const = 0;
+    virtual KUrl::List containedProjects() const = 0;
     virtual KUrl pluginDataArea( const IPlugin* ) = 0;
     virtual KSharedConfig::Ptr config() = 0;
+    virtual QUuid id() const = 0;
+
+    /**
+     * Mark session as temporary. It will then be deleted on close.
+     *
+     * This is mainly useful for unit tests etc.
+     */
+    virtual void setTemporary(bool temp) = 0;
+    virtual bool isTemporary() const = 0;
 };
 
 }
