@@ -53,6 +53,7 @@ class ExecuteScriptPlugin : public KDevelop::IPlugin, public IExecuteScriptPlugi
     //static QString useTerminalEntry;
     static QString userIdToRunEntry;
     static QString projectTargetEntry;
+    static QString outputFilteringEntry;
     
     virtual void unload();
     
@@ -64,6 +65,7 @@ class ExecuteScriptPlugin : public KDevelop::IPlugin, public IExecuteScriptPlugi
     QString environmentGroup( KDevelop::ILaunchConfiguration* ) const;
     //bool useTerminal( KDevelop::ILaunchConfiguration* ) const;
     QString scriptAppConfigTypeId() const;
+    int outputFilterModeId( KDevelop::ILaunchConfiguration* ) const;
 
     ScriptAppConfigType* m_configType;
 };
