@@ -138,8 +138,6 @@ QString toRevisionName(const KDevelop::VcsRevision& rev, QString currentRevision
 QString revisionInterval(const KDevelop::VcsRevision& rev, const KDevelop::VcsRevision& limit)
 {
     QString ret;
-//     qDebug() << "prrrrrrrrrr" << toRevisionName(rev, "xxx") << toRevisionName(limit, "yyy");
-    
     if(rev.revisionType()==VcsRevision::Special &&
                 rev.revisionValue().value<VcsRevision::RevisionSpecialType>()==VcsRevision::Start) //if we want it to the begining just put the revisionInterval
         ret = toRevisionName(limit, QString());
@@ -155,8 +153,6 @@ QString revisionInterval(const KDevelop::VcsRevision& rev, const KDevelop::VcsRe
                 ret = src+".."+dst;
         }
     }
-    
-//     qDebug() << "=======>" << ret;
     return ret;
 }
 
@@ -950,12 +946,20 @@ void GitPlugin::parseLogOutput(const DVcsJob * job, QList<DVcsEvent>& commits) c
 
 void GitPlugin::parseGitLogOutput(DVcsJob * job)
 {
-    QList<QVariant> commits;
     static QRegExp commitRegex( "^commit (\\w{8})\\w{32}" );
     static QRegExp infoRegex( "^(\\w+):(.*)" );
     static QRegExp modificationsRegex("(\\d+)\\s+(\\d+)\\s+(.+)"); //18      2       shell/workingsets/workingsetwidget.cpp
 
+    QList<QVariant> commits;
+
     QString contents = job->output();
+    // check if git-log returned anything
+    if (contents.isEmpty()) {
+        job->setResults(commits); // empty list
+        return;
+    }
+
+    // start parsing the output
     QTextStream s(&contents);
 
     VcsEvent item;
@@ -1319,7 +1323,11 @@ class GitVcsLocationWidget : public KDevelop::StandardVcsLocationWidget
     public:
         GitVcsLocationWidget(QWidget* parent = 0, Qt::WindowFlags f = 0)
             : StandardVcsLocationWidget(parent, f) {}
-        virtual bool isCorrect() const { return true; }
+
+        virtual bool isCorrect() const
+        {
+            return !url().isEmpty();
+        }
 };
 
 KDevelop::VcsLocationWidget* GitPlugin::vcsLocation(QWidget* parent) const
