@@ -88,6 +88,7 @@ public:
     virtual KDevelop::VcsJob* resolve(const KUrl::List& localLocations, RecursionMode recursion);
     virtual KDevelop::VcsJob* update(const KUrl::List& localLocations, const KDevelop::VcsRevision& rev, RecursionMode recursion);
     KDevelop::VcsLocationWidget* vcsLocation(QWidget* parent) const;
+    virtual void setupCommitMessageEditor(const KUrl& localLocation, KTextEdit* editor) const;
     //End of
 
     KDevelop::VcsJob* add(const KUrl::List& localLocations,
@@ -114,16 +115,13 @@ public:
     KDevelop::VcsJob* init(const KUrl & directory);
 
     // Branch management
-
-    KDevelop::DVcsJob* switchBranch(const QString &repository,
-                          const QString &branch);
-    KDevelop::DVcsJob* branch(const QString &repository,
-                    const QString &basebranch = QString(),
-                    const QString &branch = QString(),
-                    const QStringList &args = QStringList());
-
-    QString curBranch(const QString &repository);
-    QStringList branches(const QString &repository);
+    KDevelop::VcsJob* tag(const KUrl& repository, const QString& commitMessage, const KDevelop::VcsRevision& rev, const QString& tagName);
+    KDevelop::VcsJob* branch(const KUrl& repository, const KDevelop::VcsRevision& rev, const QString& branchName);
+    KDevelop::VcsJob* branches(const KUrl& repository);
+    KDevelop::VcsJob* currentBranch(const KUrl& repository);
+    KDevelop::VcsJob* deleteBranch(const KUrl& repository, const QString& branchName);
+    KDevelop::VcsJob* switchBranch(const KUrl& repository, const QString& branchName);
+    KDevelop::VcsJob* renameBranch(const KUrl& repository, const QString& oldBranchName, const QString& newBranchName);
 
     //graph helpers
     QList<DVcsEvent> getAllCommits(const QString &repo);
@@ -150,7 +148,7 @@ protected:
     KDevelop::DVcsJob* lsFiles(const QDir &repository,
                      const QStringList &args,
                      KDevelop::OutputJob::OutputJobVerbosity verbosity = KDevelop::OutputJob::Verbose);
-    KDevelop::DVcsJob* gitRevList(const QString &repository,
+    KDevelop::DVcsJob* gitRevList(const QString &directory,
                         const QStringList &args);
     KDevelop::DVcsJob* gitRevParse(const QString &repository,
                          const QStringList &args,
@@ -164,6 +162,8 @@ private slots:
     void parseGitStatusOutput(KDevelop::DVcsJob* job);
     void parseGitStatusOutput_old(KDevelop::DVcsJob* job);
     void parseGitVersionOutput(KDevelop::DVcsJob* job);
+    void parseGitBranchOutput(KDevelop::DVcsJob* job);
+    void parseGitCurrentBranch(KDevelop::DVcsJob* job);
     
     void ctxPushStash();
     void ctxPopStash();
@@ -191,4 +191,6 @@ private:
     QString m_errorDescription;
 };
 
+QVariant runSynchronously(KDevelop::VcsJob* job);
+
 #endif
