@@ -50,7 +50,7 @@
 
 #include "toolviewdata.h"
 
-OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
+OutputWidget::OutputWidget(QWidget* parent, const ToolViewData* tvdata)
     : QWidget( parent )
     , tabwidget(0)
     , stackwidget(0)
@@ -120,6 +120,7 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
         filterInput->setMaximumWidth(150);
         filterInput->setMinimumWidth(100);
         filterInput->setClickMessage(i18n("Search..."));
+        filterInput->setClearButtonShown(true);
         filterInput->setToolTip(i18n("Enter a wild card string to filter the output view"));
         filterAction = new QWidgetAction(this);
         filterAction->setDefaultWidget(filterInput);
@@ -160,7 +161,6 @@ OutputWidget::OutputWidget(QWidget* parent, ToolViewData* tvdata)
 void OutputWidget::addOutput( int id )
 {
     QTreeView* listview = createListView(id);
-    listview->setSelectionMode(QAbstractItemView::ContiguousSelection);
     setCurrentWidget( listview );
     connect( data->outputdata.value(id), SIGNAL(modelChanged(int)), this, SLOT(changeModel(int)));
     connect( data->outputdata.value(id), SIGNAL(delegateChanged(int)), this, SLOT(changeDelegate(int)));
@@ -182,11 +182,7 @@ void OutputWidget::setCurrentWidget( QTreeView* view )
 void OutputWidget::changeDelegate( int id )
 {
     if( data->outputdata.contains( id ) && views.contains( id ) ) {
-        QAbstractItemDelegate* delegate = data->outputdata.value(id)->delegate.data();
-        if (!delegate) {
-            kWarning() << "OutputWidget delegate was deleted for id" << id << data->outputdata.value(id)->title;
-        }
-        views.value(id)->setItemDelegate(delegate);
+        views.value(id)->setItemDelegate(data->outputdata.value(id)->delegate);
     } else {
         addOutput(id);
     }
@@ -383,6 +379,19 @@ void OutputWidget::activate(const QModelIndex& index)
     }
 }
 
+static QTreeView* createFocusedTreeView( QWidget* parent )
+{
+    QTreeView* listview = new KDevelop::FocusedTreeView(parent);
+    listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
+    listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
+    listview->setHeaderHidden(true);
+    listview->setUniformRowHeights(true);
+    listview->setRootIsDecorated(false);
+    listview->setSelectionMode( QAbstractItemView::ContiguousSelection );
+
+    return listview;
+}
+
 QTreeView* OutputWidget::createListView(int id)
 {
     QTreeView* listview = 0;
@@ -391,12 +400,8 @@ QTreeView* OutputWidget::createListView(int id)
         if( data->type & KDevelop::IOutputView::MultipleView || data->type & KDevelop::IOutputView::HistoryView )
         {
             kDebug() << "creating listview";
-            listview = new KDevelop::FocusedTreeView(this);
-            listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
-            listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
-            listview->setHeaderHidden(true);
-            listview->setRootIsDecorated(false);
-            
+            listview = createFocusedTreeView(this);
+
             views[id] = listview;
             connect( listview, SIGNAL(activated(QModelIndex)),
                      this, SLOT(activate(QModelIndex)));
@@ -415,11 +420,7 @@ QTreeView* OutputWidget::createListView(int id)
         {
             if( views.isEmpty() )
             {
-                listview = new KDevelop::FocusedTreeView(this);
-                listview->setEditTriggers( QAbstractItemView::NoEditTriggers );
-                listview->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOn); //Always enable the scrollbar, so it doesn't flash around
-                listview->setRootIsDecorated(false);
-                listview->setHeaderHidden(true);
+                listview = createFocusedTreeView(this);
 
                 layout()->addWidget( listview );
                 connect( listview, SIGNAL(activated(QModelIndex)),
