@@ -52,6 +52,7 @@
 #include "../debugger/variable/variablewidget.h"
 #include "../debugger/framestack/framestackmodel.h"
 #include "../debugger/framestack/framestackwidget.h"
+#include <KXMLGUIFactory>
 
 
 namespace KDevelop {
@@ -100,11 +101,28 @@ private:
 
 DebugController::DebugController(QObject *parent)
     : IDebugController(parent), KXMLGUIClient(),
+      m_continueDebugger(0), m_stopDebugger(0),
+      m_interruptDebugger(0), m_runToCursor(0),
+      m_jumpToCursor(0), m_stepOver(0),
+      m_stepIntoInstruction(0), m_stepInto(0),
+      m_stepOverInstruction(0), m_stepOut(0),
+      m_toggleBreakpoint(0),
       m_breakpointModel(new BreakpointModel(this)),
-      m_variableCollection(new VariableCollection(this))
+      m_variableCollection(new VariableCollection(this)),
+      m_uiInitialized(false)
 {
     setComponentData(KComponentData("kdevdebugger"));
     setXMLFile("kdevdebuggershellui.rc");
+}
+
+void DebugController::initialize()
+{
+}
+
+void DebugController::initializeUi()
+{
+    if (m_uiInitialized) return;
+    m_uiInitialized = true;
 
     if((Core::self()->setupFlags() & Core::NoUi)) return;
     setupActions();
@@ -134,17 +152,16 @@ DebugController::DebugController(QObject *parent)
             this,
             SLOT(partAdded(KParts::Part*)));
 
-}
 
-void DebugController::initialize()
-{
+    ICore::self()->uiController()->activeMainWindow()->guiFactory()->addClient(this);
+
     stateChanged("ended");
 }
 
 
 void DebugController::cleanup()
 {
-    if (m_currentSession) m_currentSession->stopDebugger();
+    if (m_currentSession) m_currentSession.data()->stopDebugger();
 }
 
 DebugController::~DebugController()
@@ -174,7 +191,7 @@ void DebugController::partAdded(KParts::Part* part)
 
 IDebugSession* DebugController::currentSession()
 {
-    return m_currentSession;
+    return m_currentSession.data();
 }
 
 void DebugController::setupActions()
@@ -269,7 +286,8 @@ void DebugController::setupActions()
     connect(action, SIGNAL(triggered(bool)), this, SLOT(stepOut()));
     ac->addAction("debug_stepout", action);
 
-    m_toggleBreakpoint = action = new KAction(i18n("Toggle Breakpoint"), this);
+    m_toggleBreakpoint = action = new KAction(KIcon("script-error"), i18n("Toggle Breakpoint"), this);
+    action->setShortcut( i18n("Ctrl+Alt+B") );
     action->setToolTip(i18n("Toggle breakpoint"));
     action->setWhatsThis(i18n("<b>Toggle breakpoint</b><p>Toggles the breakpoint at the current line in editor.</p>"));
     connect(action, SIGNAL(triggered(bool)), this, SLOT(toggleBreakpoint()));
@@ -285,7 +303,7 @@ void DebugController::addSession(IDebugSession* session)
 
     //TODO support multiple sessions
     if (m_currentSession) {
-        m_currentSession->stopDebugger();
+        m_currentSession.data()->stopDebugger();
     }
     m_currentSession = session;
         
@@ -357,22 +375,24 @@ void DebugController::debuggerStateChanged(KDevelop::IDebugSession::DebuggerStat
 {
     Q_ASSERT(dynamic_cast<IDebugSession*>(sender()));
     IDebugSession* session = static_cast<IDebugSession*>(sender());
-    kDebug() << session << state << "current" << m_currentSession;
-    if (session == m_currentSession) {
+    kDebug() << session << state << "current" << m_currentSession.data();
+    if (session == m_currentSession.data()) {
         updateDebuggerState(state, session);
     }
 
     if (state == IDebugSession::EndedState) {
-        if (session == m_currentSession) {
-            m_currentSession = 0;
+        if (session == m_currentSession.data()) {
+            m_currentSession.clear();
             emit currentSessionChanged(0);
-            Sublime::MainWindow* mainWindow = Core::self()->uiControllerInternal()->activeSublimeWindow();
-            if (mainWindow && mainWindow->area()->objectName() != "code") {
-                QString workingSet = mainWindow->area()->workingSet();
-                ICore::self()->uiController()->switchToArea("code", IUiController::ThisWindow);
-                mainWindow->area()->setWorkingSet(workingSet);
+            if (!Core::self()->shuttingDown()) {
+                Sublime::MainWindow* mainWindow = Core::self()->uiControllerInternal()->activeSublimeWindow();
+                if (mainWindow && mainWindow->area()->objectName() != "code") {
+                    QString workingSet = mainWindow->area()->workingSet();
+                    ICore::self()->uiController()->switchToArea("code", IUiController::ThisWindow);
+                    mainWindow->area()->setWorkingSet(workingSet);
+                }
+                ICore::self()->uiController()->findToolView(i18n("Debug"), 0, IUiController::Raise);
             }
-            ICore::self()->uiController()->findToolView(i18n("Debug"), 0, IUiController::Raise);
         }
         session->deleteLater();
     }
@@ -390,7 +410,6 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
         case IDebugSession::StoppingState:
             kDebug() << "new state: stopped";
             stateChanged("stopped");
-            clearExecutionPoint();
             //m_restartDebugger->setEnabled(session->restartAvaliable());
             break;
         case IDebugSession::StartingState:
@@ -403,12 +422,10 @@ void DebugController::updateDebuggerState(IDebugSession::DebuggerState state, ID
             kDebug() << "new state: active";
             stateChanged("active");
             //m_restartDebugger->setEnabled(false);
-            clearExecutionPoint();
             break;
         case IDebugSession::EndedState:
             kDebug() << "new state: ended";
             stateChanged("ended");
-            clearExecutionPoint();
             //m_restartDebugger->setEnabled(false);
             break;
     }
@@ -428,7 +445,7 @@ ContextMenuExtension DebugController::contextMenuExtension( Context* context )
     if (!econtext)
         return menuExt;
 
-    if (m_currentSession && m_currentSession->isRunning()) {
+    if (m_currentSession && m_currentSession.data()->isRunning()) {
         menuExt.addAction( KDevelop::ContextMenuExtension::DebugGroup, m_runToCursor);
     }
 
@@ -441,61 +458,61 @@ ContextMenuExtension DebugController::contextMenuExtension( Context* context )
 #if 0
 void DebugController::restartDebugger() {
     if (m_currentSession) {
-        m_currentSession->restartDebugger();
+        m_currentSession.data()->restartDebugger();
     }
 }
 #endif
 
 void DebugController::stopDebugger() {
     if (m_currentSession) {
-        m_currentSession->stopDebugger();
+        m_currentSession.data()->stopDebugger();
     }
 }
 void DebugController::interruptDebugger() {
     if (m_currentSession) {
-        m_currentSession->interruptDebugger();
+        m_currentSession.data()->interruptDebugger();
     }
 }
 
 void DebugController::run() {
     if (m_currentSession) {
-        m_currentSession->run();
+        m_currentSession.data()->run();
     }
 }
 
 void DebugController::runToCursor() {
     if (m_currentSession) {
-        m_currentSession->runToCursor();
+        m_currentSession.data()->runToCursor();
     }
 }
 void DebugController::jumpToCursor() {
     if (m_currentSession) {
-        m_currentSession->jumpToCursor();
+        m_currentSession.data()->jumpToCursor();
     }
 }
 void DebugController::stepOver() {
     if (m_currentSession) {
-        m_currentSession->stepOver();
+        m_currentSession.data()->stepOver();
     }
 }
 void DebugController::stepIntoInstruction() {
     if (m_currentSession) {
-        m_currentSession->stepIntoInstruction();
+        m_currentSession.data()->stepIntoInstruction();
     }
 }
 void DebugController::stepInto() {
     if (m_currentSession) {
-        m_currentSession->stepInto();
+        m_currentSession.data()->stepInto();
     }
 }
 void DebugController::stepOverInstruction() {
     if (m_currentSession) {
-        m_currentSession->stepOverInstruction();
+        m_currentSession.data()->stepOverInstruction();
     }
 }
 void DebugController::stepOut() {
     if (m_currentSession) {
-        m_currentSession->stepOut();
+        m_currentSession.data()->stepOut();
     }
 }
 
