@@ -459,7 +459,7 @@ void MainWindowPrivate::dockBarContextMenuRequested(Qt::DockWidgetArea area, con
         {
             QAction* action = new QAction(it.value()->statusIcon(), it.value()->title(), &menu);
             action->setIcon(it.value()->statusIcon());
-            if (Core::self()->uiControllerInternal()->toolViewPresent(it.value(), m_mainWindow->area())) {
+            if (!it.key()->allowMultiple() && Core::self()->uiControllerInternal()->toolViewPresent(it.value(), m_mainWindow->area())) {
                 action->setDisabled(true);
             }
             actionToFactory.insert(action, it.key());
