@@ -463,7 +463,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
         else
         {
             kWarning() << "Loading plugin '" << pluginId
-                << "' failed, KPluginLoader reported error: '" << endl <<
+                << "' failed, KServiceTypeTrader reported error: '" << endl <<
                 str_error << "'";
         }
     }
@@ -589,7 +589,7 @@ QList<IPlugin*> PluginController::allPluginsForExtension(const QString &extensio
         if (plugin)
             plugins << plugin;
         else
-            kWarning(9501) << "Null plugin retrieved! Loading error?";
+            kWarning(9501) << "Null plugin retrieved! Loading error?" << extension << constraints;
     }
     return plugins;
 }
